HelpPageGenerator (py4j-java 0.10.9.4 API)
Date: 2022-03-16

py4j.model

## Class HelpPageGenerator

- java.lang.Object
- - py4j.model.HelpPageGenerator

-     public class HelpPageGenerator
      extends java.lang.Object

  The HelpPageGenerator generates a help page (a String) for a class or a method.

- - ### Field Summary

    Fields
    Modifier and Type | Field and Description
    --- | ---
    `static java.lang.String` | `DOUBLE_LINES`
    `static java.lang.String` | `INDENT`
    `static java.lang.String` | `PREFIX`
    `static java.lang.String` | `PREFIX_INDENT`
    `static java.lang.String` | `PREFIX_SEPARATOR`
    `static java.lang.String` | `SEPARATOR`

  - ### Constructor Summary

    Constructors
    Constructor and Description
    `HelpPageGenerator()`

  - ### Method Summary

    All Methods Static Methods Concrete Methods
    Modifier and Type | Method and Description
    --- | ---
    `static java.lang.String` | `getHelpPage(Py4JClass clazz, java.lang.String pattern, boolean shortName)`
    `static java.lang.String` | `getHelpPage(Py4JMethod method, boolean shortName)`
    `static java.util.regex.Pattern` | `getRegex(java.lang.String pattern)`

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

- - ### Field Detail

    - #### PREFIX

          public static final java.lang.String PREFIX

      See Also:
        Constant Field Values

    - #### INDENT

          public static final java.lang.String INDENT

      See Also:
        Constant Field Values

    - #### PREFIX_INDENT

          public static final java.lang.String PREFIX_INDENT

      See Also:
        Constant Field Values

    - #### DOUBLE_LINES

          public static final java.lang.String DOUBLE_LINES

      See Also:
        Constant Field Values

    - #### SEPARATOR

          public static final java.lang.String SEPARATOR

      See Also:
        Constant Field Values

    - #### PREFIX_SEPARATOR

          public static final java.lang.String PREFIX_SEPARATOR

      See Also:
        Constant Field Values

  - ### Constructor Detail

    - #### HelpPageGenerator

          public HelpPageGenerator()

  - ### Method Detail

    - #### getHelpPage

          public static final java.lang.String getHelpPage(Py4JClass clazz,
                                                           java.lang.String pattern,
                                                           boolean shortName)

      Parameters:
        `clazz` -
        `pattern` - Star pattern.
        `shortName` -
      Returns:

    - #### getHelpPage

          public static final java.lang.String getHelpPage(Py4JMethod method,
                                                           boolean shortName)

    - #### getRegex

          public static final java.util.regex.Pattern getRegex(java.lang.String pattern)